/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.readers.files;

// REMPL API from com.rempl:rempl-api classes
import com.rempl.api.Logger;
import com.rempl.api.Model;
import com.rempl.api.Reader;
import com.rempl.api.Rempler;

/**
 * Reader of files from filesystem.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: FilesReader.java 1364 2011-05-08 18:55:07Z guard $
 */
public final class FilesReader implements Reader {

    /**
     * The {@link Rempler} we're working for.
     * @see #setRempler(Rempler)
     */
    private Rempler rempler;

    /**
     * Public ctor.
     */
    public FilesReader() {
        this.rempler = null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void setRempler(final Rempler rpr) {
        this.rempler = rpr;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean read(final Model model) throws java.io.IOException {
        Logger.debug(
            this,
            "#read(%s): it's a stub, nothing read (rempler: %s)",
            model.getClass().getName(),
            this.rempler.getClass().getName()
        );
        return false;
    }

}
